﻿using System;
using System.Configuration;
using System.IO.Ports;
using System.Threading;

/*
 * 	Author: 	J.Fàbregas
 *	Projecte:	Control de la gravació/lectura targetes inductives pels vehicles amb Matèria Primera
 *	Objectiu:   Permet la comunicació amb la báscula utilitzant el port de comunicacions.
 *	Modificat:  Gener-2015
*/

namespace ControlWeight.BL
{
    public class Comunicacions_Densimetre
    {
        public static SerialPort _serialPort;

        public class Targeta
        {
            public String DataEntrada { get; set; }
            public String Entrada { get; set; }
            public String Matricula { get; set; }
            public String Remolc { get; set; }
            public String Palada { get; set; }
            public String Sector { get; set; }
            public String Block0 { get; set; }
            public String Block1 { get; set; }
            public String Block2 { get; set; }
            public String Block3 { get; set; }
        }

        public static Boolean InitSerialPort()
        {
            Boolean bRetorn;
            bRetorn = true;

            try
            {
                String nomPort = ConfigurationManager.AppSettings["PORT_2"];

                if (_serialPort == null)
                {
                    _serialPort = new System.IO.Ports.SerialPort(nomPort);
                }

                if (_serialPort.IsOpen == false) //if not open, open the port
                {
                    _serialPort.BaudRate = Convert.ToInt32(ConfigurationManager.AppSettings["BAU_2"]);
                    _serialPort.DataBits = Convert.ToInt32(ConfigurationManager.AppSettings["NUMBITS_2"]);
                    _serialPort.StopBits = System.IO.Ports.StopBits.One;
                    _serialPort.Parity = System.IO.Ports.Parity.None;
                    _serialPort.Handshake = System.IO.Ports.Handshake.None;
                    _serialPort.ReadTimeout = 500000;
                    _serialPort.WriteTimeout = 500000;
                    _serialPort.Open();

                    if (_serialPort.IsOpen == true)
                    {
                        bRetorn = true;
                    }
                    else
                    {
                        bRetorn = false;
                    }
                }
                return bRetorn;
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.ToString());
                return bRetorn;
            }
        }


        public static Boolean CloseSerialPort()
        {
            Boolean bRetorn;
            bRetorn = true;

            if (_serialPort != null)
            {
                try
                {
                    _serialPort.DiscardInBuffer();
                    _serialPort.Close();
                    _serialPort.Dispose();
                    _serialPort = null;
                    bRetorn = true;
                }
                catch (Exception)
                {
                    bRetorn = false;
                }
            }
            return bRetorn;
        }


        public static String LecturaBufferTargeta()
        {
            String buffer;
            buffer = "";

            try
            {
                buffer = _serialPort.ReadExisting();
                /*
                 * Lectura d'una linia del Buffer, l'enviament de les dades per part del dispositiu
                 * Lector/Gravador de targetes inductives
                 */
                Thread.Sleep(2000);

                if (_serialPort.BytesToRead > 0)
                {
                    buffer = _serialPort.ReadLine();
                    buffer = buffer.Substring(4, 6);
                }
                else
                {
                    string i = "";
                }

            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.ToString());
            }
            return buffer;
        }


        public static void GravacioBufferTargeta(Targeta tg)
        {
            String buffer;
            buffer = "";

            String Inf_Block0;
            String Inf_Block1;
            String Inf_Block2;
            String Inf_Block3;
            
            int x;
            String tmp;
            string Orden;
            Single t;
            String[] aReturn = new String[5];

            try
            {
                 //Comprovació de que les dades que s'han de gravar a la targeta i siguin totes.
                 //El remolc no es comprova perquè por ser que no n'hi hagi.
                if (String.IsNullOrEmpty(tg.DataEntrada))
                {
                    aReturn[0] = Convert.ToString(1);
                }
                else if (String.IsNullOrEmpty(tg.Entrada))
                {
                    aReturn[0] = Convert.ToString(2);
                }
                else if (String.IsNullOrEmpty(tg.Matricula))
                {
                    aReturn[0] = Convert.ToString(3);
                }
                else if (String.IsNullOrEmpty(tg.Palada))
                {
                    aReturn[0] = Convert.ToString(6);
                }
                else if (String.IsNullOrEmpty(tg.Sector))
                {
                    aReturn[0] = Convert.ToString(7);
                }
                else if (String.IsNullOrEmpty(tg.Block0) || String.IsNullOrEmpty(tg.Block1) || String.IsNullOrEmpty(tg.Block2) || String.IsNullOrEmpty(tg.Block3))
                {
                    aReturn[0] = Convert.ToString(8);
                }

                Orden = String.Concat("Qsl" + tg.Sector + "aaffffffffffffw" + tg.Block0  + "\r" + "\n");
                _serialPort.WriteLine(Orden);
                _serialPort.DiscardOutBuffer();

                buffer = String.Concat(buffer + _serialPort.ReadExisting());

                //'Tractament "Matricula"

                Orden = String.Concat("l" + tg.Sector + "aaffffffffffffw" + tg.Block1 + "\r" + "\n");
                _serialPort.WriteLine(Orden);
                _serialPort.DiscardOutBuffer();

                buffer = String.Concat(buffer + _serialPort.ReadExisting());

                _serialPort.DiscardOutBuffer();

                buffer = String.Concat(buffer + _serialPort.ReadExisting());

                /*
                 * Lectura d'una linia del Buffer, l'enviament de les dades per part del dispositiu
                 * Lector/Gravador de targetes inductives
                 */
                Thread.Sleep(2000);

                if (_serialPort.BytesToWrite > 0)
                {
                    _serialPort.WriteLine(buffer);
                }
                else
                {
                    string i = "";
                }

            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.ToString());
            }
            //return aReturn;
        }

    }
}
