﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Security.Cryptography;
using System.Text;
using System.Threading.Tasks;
using ControlWeight.WCF;

/*
 * 	Author: 	J.Fàbregas
 *	Projecte:	Control del pes per a les entrades/sortides de vehicles amb Matèria Primera
 *	Objectiu:   Permet fer el CRUD de la taula d'usuaris.
 *	Modificat:  Gener-2015
*/

namespace ControlWeight.BL
{
    public class GestioUsuaris
    {
        static ServiceReference1.ServicioControlWeightClient client = new ServiceReference1.ServicioControlWeightClient();

        public static Boolean GravarRegistre(String cTipus, Usuario user)
        {
            Boolean bResultat;
            bResultat = true;
            switch (cTipus)
            {
                case "U":
                    
                    if (client.ActualitzarUsuari(user.usuari, user.email, user.nom ,(Boolean)user.actiu, (Guid)user.perfil, user.pass))
                    {
                        bResultat = true;
                    }
                    else
                    {
                        bResultat = false;
                    }
                    break;
                case "I":

                    user.idu = Guid.NewGuid();
                    if (client.AfegirUsuari(user))
                    {
                        bResultat = true;
                    }
                    else
                    {
                        bResultat = false;
                    }
                    break;
                case "D":
                    if (client.EliminarUsuari(user.usuari))
                    {
                        bResultat = true;
                    }
                    else
                    {
                        bResultat = false;
                    }
                    break;
                default:
                    bResultat = false;
                    break;
            }
            return bResultat;
        }


        public static List<Usuario> LlistaUsuaris()
        {
            List<Usuario> _lstUsuaris = new List<Usuario>();

            _lstUsuaris = client.LlistaUsuaris().ToList();

            return _lstUsuaris;
        }


        public static Boolean ConsultarRegistre(Usuario user)
        {
            Boolean bResultat;
            bResultat = false;

            foreach (var q in client.ConsultarUsuari (user.usuari))
            {
                if (q.nom != null)
                    bResultat = true;
            }
            return bResultat;
        }


        public static String GeneradorDeHash(String textPerXifrar)
        {
            //Variables  sal, texte, arxiuSortida
            int quantitatDeSal = 4;
            //string textPerXifrar;
            string clauXifrada;

            //Console.Write("Password per xifrar : ");
            //textPerXifrar = Console.ReadLine();
            //Console.Write("Arxiu desti : ");
            //arxiuDesti = Console.ReadLine();

            // Generador de nombre aleatoris
            RandomNumberGenerator rng = RandomNumberGenerator.Create();
            byte[] salero = new byte[quantitatDeSal];
            // Genera nombres aletoris diferents de zero i o posem dins la matriu
            rng.GetNonZeroBytes(salero);
            // Convertim el texte password a una matriu de bytes
            byte[] bytesDeDades = Encoding.UTF8.GetBytes(textPerXifrar);
            // Generem un altre matriu per desar les dades + la sal
            byte[] datosSalados = new byte[salero.Length + bytesDeDades.Length];
            // Copiar la sal a dadesSalades
            Array.Copy(salero, 0, datosSalados, 0, salero.Length);
            Array.Copy(bytesDeDades, 0, datosSalados, salero.Length, bytesDeDades.Length);
            // Algorisme per crear el Hash
            SHA1CryptoServiceProvider csp = new SHA1CryptoServiceProvider();
            Byte[] bytesAmbHash = csp.ComputeHash(datosSalados);
            byte[] resultatDeBytes = new byte[salero.Length + bytesAmbHash.Length];
            Array.Copy(salero, 0, resultatDeBytes, 0, salero.Length);
            Array.Copy(bytesAmbHash, 0, resultatDeBytes, salero.Length, bytesAmbHash.Length);
            clauXifrada = Convert.ToBase64String(resultatDeBytes);
            return clauXifrada;
        }


        public static String ClauUsuari(String usuari)
        {
            try
            {
                String sPass = client.ConsultarUsuari(usuari)[0].pass.ToString();
                return sPass;
            }
            catch (Exception)
            {
                return null;
            }
        }

        
        public static String ConsultaUsuari(String usuari, String sCamp)
        {
            String sResultat;
            sResultat = "";

            try
            {
                 foreach (var q in client.ConsultarUsuari(usuari))
                 {
                     if (q.usuari != null)
                         switch (sCamp)
                         {
                             case "eMail":
                                 sResultat = q.email;
                                 break;
                             case "actiu":
                                sResultat = q.actiu.ToString();
                                break;
                             case "perfil":
                                sResultat = q.perfil.ToString ();
                                break;
                         }
                 }
            }
            catch (Exception ex)
            {
                sResultat = null;
            }

            return sResultat;

        }
    }
}
