﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

/*
 * 	Author: 	J.Fàbregas
 *	Projecte:	Control del pes per a les entrades/sortides de vehicles amb Matèria Primera
 *	Objectiu:   Implementació dels serveis que permeten la gestió de la aplicació.
 *	Modificat:  Gener-2015
*/


namespace ControlWeight.WCF
{
    class ServicioControlWeight:IServicioControlWeight
    {
        private String perfil = "";
        private int numEntrada;

        #region Article //Gestionar la quantitat d'articles a retornar pel servei

        public bool AfegirArticle(Articulo article)
        {
            ControlWeightEntities bd = new ControlWeightEntities();
            bd.Articulos.Add(article);
            bd.SaveChanges();
            return true;       
        }


        public bool EliminarArticle(string codArticle)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                var registre = (from o in bd.Articulos
                                where o.Codigo == codArticle
                                select o).Single();

                bd.Articulos.Remove(registre);
                bd.SaveChanges();
                return true;
            }
        }


        public List<Articulo> LlistaArticles(String ordre)
        {
            ControlWeightEntities contexte;

            using (contexte = new ControlWeightEntities())
            {
                List<Articulo> _lstArticles = new List<Articulo>();

                foreach (var q in contexte.Articulos)
                {
                    Articulo pdata = new Articulo();
                    pdata.Fabrica = q.Fabrica;
                    pdata.Codigo = q.Codigo;
                    pdata.Descripcion = q.Descripcion;
                    pdata.Lugar_Descarga = q.Lugar_Descarga;
                    pdata.Numero_ID_TPC = q.Numero_ID_TPC;
                    pdata.Clase_Apartado_Letra = q.Clase_Apartado_Letra;
                    pdata.idUnico = q.idUnico;

                    _lstArticles.Add(pdata);
                }
                if (ordre == "C")
                {
                    _lstArticles = _lstArticles.OrderBy(q => q.Codigo).ToList();
                }
                else
                {
                    _lstArticles = _lstArticles.OrderBy(q => q.Descripcion).ToList();
                }
                return _lstArticles;
            }
        }


        public List<Articulo> ConsultarArticle(string codArticle)
        {
            List<Articulo> _lstArticles = new List<Articulo>();

            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Articulos
                                    where o.Codigo == codArticle
                                    select o).Single();
                    Articulo pdata = new Articulo();
                    pdata.Fabrica = registre.Fabrica;
                    pdata.Codigo = registre.Codigo;
                    pdata.Descripcion = registre.Descripcion;
                    pdata.Lugar_Descarga = registre.Lugar_Descarga;
                    pdata.Numero_ID_TPC = registre.Numero_ID_TPC;
                    pdata.Clase_Apartado_Letra = registre.Clase_Apartado_Letra;
                    pdata.idUnico = registre.idUnico;
                    _lstArticles.Add(pdata);
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstArticles;
        }


        public bool ActualitzarArticle(String codArticle, String sDescripcio, String codLlocDescarrega, String numID_TPC, String claseApartLletra)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Articulos
                                    where o.Codigo == codArticle
                                    select o).Single();
                    registre.Descripcion = sDescripcio;
                    registre.Lugar_Descarga = codLlocDescarrega;
                    registre.Numero_ID_TPC = numID_TPC;
                    registre.Clase_Apartado_Letra = claseApartLletra;
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                    return false;
                }
            }
        }
        #endregion Article

        #region LlocDescarrega

        public bool AfegirLlocDescarrega(LugarDescarga llocDescarrega)
        {
            try
            {
                ControlWeightEntities bd = new ControlWeightEntities();
                bd.LugarDescargas.Add(llocDescarrega);
                bd.SaveChanges();
                return true;
            }
            catch (Exception)
            {
                return false;
            }
        }


        public bool EliminarLlocDescarrega(String codiDescarrega)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.LugarDescargas
                                    where o.Codigo == codiDescarrega
                                    select o).Single();

                    bd.LugarDescargas.Remove(registre);
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception)
                {
                    return false;
                }
            }
        }


        public List<LugarDescarga> LlistaLlocsDescarrega()
        {
            ControlWeightEntities contexte;

            using (contexte = new ControlWeightEntities())
            {
                List<LugarDescarga> _lstLlocsDescarrega = new List<LugarDescarga>();

                foreach (var q in contexte.LugarDescargas)
                {
                    LugarDescarga pdata = new LugarDescarga();
                    pdata.Fabrica = q.Fabrica;
                    pdata.Codigo = q.Codigo;
                    pdata.Descripcion = q.Descripcion;
                    pdata.idUnico = q.idUnico;

                    _lstLlocsDescarrega.Add(pdata);
                }
                return _lstLlocsDescarrega;
            }           
        }


        public List<LugarDescarga> ConsultarLlocDescarrega(String codiDescarrega)
        {
            List<LugarDescarga> _lstLlocDescarrega = new List<LugarDescarga>();

            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.LugarDescargas
                                    where o.Codigo == codiDescarrega
                                    select o).Single();
                    LugarDescarga pdata = new LugarDescarga();
                    pdata.Codigo = registre.Codigo;
                    pdata.Descripcion = registre.Descripcion;
                    pdata.idUnico = registre.idUnico;
                    _lstLlocDescarrega.Add(pdata);
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstLlocDescarrega;
        }


        public bool ActualitzarLlocDescarrega(String codiDescarrega, String sDescripcio)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.LugarDescargas
                                    where o.Codigo == codiDescarrega
                                    select o).Single();
                    registre.Descripcion = sDescripcio;
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                    return false;
                }
            }            
        }
        #endregion LlocDescarrega

        #region Matricula

        public bool AfegirMatricula(Matricula matricula)
        {
            throw new NotImplementedException();
        }

        public bool EliminarMatricula(string matricula)
        {
            throw new NotImplementedException();
        }

        public string[] LlistaMatricules()
        {
            throw new NotImplementedException();
        }

        public string[] ConsultarMatricula(string matricula)
        {
            throw new NotImplementedException();
        }

        public bool ActualitzarMatricula(Matricula matricula)
        {
            throw new NotImplementedException();
        }
        #endregion Matricula

        #region Proveidor

        public Boolean AfegirProveidor(Proveedor proveidor)
        {
            try
            {
                ControlWeightEntities bd = new ControlWeightEntities();
                bd.Proveedores.Add(proveidor);
                bd.SaveChanges();
                return true;       
            }
            catch (Exception)
            {
                return false;
            }

        }


        public Boolean EliminarProveidor(String codiProveidor)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Proveedores
                                    where o.Codigo == codiProveidor
                                    select o).Single();

                    bd.Proveedores.Remove(registre);
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception)
                {
                    return false;
                }
            }
        }


        public List<Proveedor> LlistaProveidors(String ordre)
        {
            List<Proveedor> _lstProveidors = new List<Proveedor>();

            ControlWeightEntities contexte;

            using (contexte = new ControlWeightEntities())
            {
                try
                {
                    foreach (var q in contexte.Proveedores)
                    {
                        Proveedor pdata = new Proveedor();
                        pdata.Fabrica = q.Fabrica;
                        pdata.Codigo = q.Codigo;
                        pdata.Descripcion = q.Descripcion;
                        pdata.idUnico = q.idUnico;

                        _lstProveidors.Add(pdata);
                    }
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }

            }

            if (ordre == "C")
            {
                _lstProveidors = _lstProveidors.OrderBy(q => q.Codigo).ToList();
            }
            else
            {
                _lstProveidors = _lstProveidors.OrderBy(q => q.Descripcion).ToList();
            }

            return _lstProveidors;
        }


        public List<Proveedor> ConsultarProveidor(String codiProveidor)
        {
            List<Proveedor> _lstProveidor = new List<Proveedor>();

            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Proveedores
                                    where o.Codigo == codiProveidor
                                    select o).Single();
                    Proveedor pdata = new Proveedor();
                    pdata.Fabrica = registre.Fabrica;
                    pdata.Codigo = registre.Codigo;
                    pdata.Descripcion = registre.Descripcion;
                    _lstProveidor.Add(pdata);
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstProveidor;
        }


        public bool ActualitzarProveidor(String codiProveidor, String sDescripcio)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Proveedores
                                    where o.Codigo == codiProveidor
                                    select o).Single();
                    registre.Descripcion = sDescripcio;
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                    return false;
                }
            }
        }

        #endregion Proveidor

        #region Transportista

        public Boolean AfegirTransportista(Transportista transportista)
        {
            try
            {
                ControlWeightEntities bd = new ControlWeightEntities();
                bd.Transportistas.Add(transportista);
                bd.SaveChanges();
                return true;
            }
            catch (Exception)
            {
                return false;
            }
        }


        public Boolean EliminarTransportista(String codTransportista)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())

            {
                try
                {
                    var registre = (from o in bd.Transportistas
                                    where o.Codigo == codTransportista
                                    select o).Single();

                    bd.Transportistas.Remove(registre);
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception)
                {
                    return false;
                }
            }
        }


        public List<Transportista> LlistaTransportistes(String ordre)
        {
            List<Transportista> _lstTransportistes = new List<Transportista>();

            ControlWeightEntities contexte;
            using (contexte = new ControlWeightEntities())

            {
                try
                {
                    foreach (var q in contexte.Transportistas)
                    {
                        Transportista pdata = new Transportista();
                        pdata.Fabrica = q.Fabrica;
                        pdata.Codigo = q.Codigo;
                        pdata.Descripcion = q.Descripcion;

                        _lstTransportistes.Add(pdata);
                    }
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            if (ordre == "C")
            {
                _lstTransportistes = _lstTransportistes.OrderBy(q => q.Codigo).ToList();
            }
            else
            {
                _lstTransportistes = _lstTransportistes.OrderBy(q => q.Descripcion).ToList();
            }
            
            return _lstTransportistes;
        }


        public List<Transportista> ConsultarTransportista(string codTransportista)
        {
            List<Transportista> _lstTransportista = new List<Transportista>();

            using (ControlWeightEntities bd = new ControlWeightEntities())

            {
                try
                {
                    var registre = (from o in bd.Transportistas
                                    where o.Codigo == codTransportista
                                    select o).Single();
                    Transportista pdata = new Transportista();
                    pdata.Fabrica = registre.Fabrica;
                    pdata.Codigo = registre.Codigo;
                    pdata.Descripcion = registre.Descripcion;
                    _lstTransportista.Add(pdata);
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstTransportista;
        }


        public bool ActualitzarTransportista(String codTransportista, String sDescripcio)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Transportistas
                                    where o.Codigo == codTransportista
                                    select o).Single();
                    registre.Descripcion = sDescripcio;
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                    return false;
                }
            }
        }
        #endregion Transportista

        #region UnitatsMesura

        public bool AfegirUnitatMesura(Unidad unitat)
        {
            ControlWeightEntities bd = new ControlWeightEntities();
            bd.Unidades.Add(unitat);
            bd.SaveChanges();
            return true;
        }


        public bool EliminarUnitatMesura(string codUnitat)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                var registre = (from o in bd.Unidades
                                where o.Codigo == codUnitat
                                select o).Single();

                bd.Unidades.Remove(registre);
                bd.SaveChanges();
                return true;
            }
        }


        public List<Unidad> LlistaUnitatsMesura()
        {
            List<Unidad> lstUnitatsMesura = new List<Unidad>();

            ControlWeightEntities contexte;
            using (contexte = new ControlWeightEntities())

            {
                try
                {
                    foreach (var q in contexte.Unidades)
                    {
                        Unidad pdata = new Unidad();
                        pdata.Fabrica = q.Fabrica;
                        pdata.Codigo = q.Codigo;
                        pdata.Descripcion = q.Descripcion;

                        pdata.idUnico = q.idUnico;

                        lstUnitatsMesura.Add(pdata);
                    }
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return lstUnitatsMesura;
        }


        public List<Unidad> ConsultarUnitatMesura(String codUnitat)
        {
            List<Unidad> _lstUnitatMesura = new List<Unidad>();

            using (ControlWeightEntities bd = new ControlWeightEntities())

            {
                try
                {
                    var registre = (from o in bd.Unidades
                                    where o.Codigo == codUnitat
                                    select o).Single();
                    Unidad pdata = new Unidad();
                    pdata.Fabrica = registre.Fabrica;
                    pdata.Codigo = registre.Codigo;
                    pdata.Descripcion = registre.Descripcion;
                    pdata.idUnico = registre.idUnico;
                    _lstUnitatMesura.Add(pdata);
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstUnitatMesura;
        }


        public bool ActualitzarUnitatMesura(String codUnitat, String sDescripcio)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Unidades
                                    where o.Codigo == codUnitat
                                    select o).Single();
                    registre.Descripcion = sDescripcio;
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                    return false;
                }
            }
        }

        #endregion UnitatsMesura

        #region Moviments

        public Boolean AfegirMoviment(Movimiento moviment)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    bd.Movimientos.Add(moviment);
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                    return false;
                }
            }
        }

        public Boolean EliminarMoviment(int numEntradaAnual)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Movimientos
                                    where o.nMovim == numEntradaAnual
                                    select o).Single();

                    bd.Movimientos.Remove(registre);
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                    return false;                    
                }
            }
        }


        public List<Movimiento> ConsultarMovimentsDia(DateTime sDataEnt)
        {
            List<Movimiento> _lstMoviment = new List<Movimiento>();

            using (ControlWeightEntities bd = new ControlWeightEntities())

            {
                try
                {
                    var registre = (from o in bd.Movimientos
                                    where o.Fecha == sDataEnt
                                    select new {o.NumeroDia,
                                                o.nMovim,
                                                o.HoraEntrada,
                                                o.HoraSalida,
                                                o.Matricula,
                                                o.TipoCarga,
                                                o.PesoEntrada,
                                                o.PesoSalida,
                                                o.Diferencia});
                   
                    foreach (var q in registre)
                    {
                        Movimiento pdata = new Movimiento();
                        //pdata.Fabrica = q.Fabrica;
                        pdata.NumeroDia = q.NumeroDia;
                        pdata.nMovim = q.nMovim;
                        pdata.HoraEntrada = q.HoraEntrada;
                        pdata.HoraSalida = q.HoraSalida;
                        pdata.Matricula = q.Matricula;
                        pdata.TipoCarga = q.TipoCarga;
                        pdata.PesoEntrada = q.PesoEntrada;
                        pdata.PesoSalida = q.PesoSalida;
                        pdata.Diferencia = q.Diferencia;

                        _lstMoviment.Add(pdata);
                        
                    }
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());                  
                }
            }
            return _lstMoviment;
        }


        public List<Movimiento> ConsultarMovimentsDensimetre(DateTime sDataEnt)
        {
            List<Movimiento> _lstMoviment = new List<Movimiento>();

            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Movimientos
                                    where (o.Fecha == sDataEnt &&
                                            (o.TipoCarga.Contains ("MN") || o.TipoCarga.Contains ("ME")))
                                    orderby o.NumeroDia descending
                                    select new
                                    {
                                        o.NumeroDia,
                                        o.HoraEntrada,
                                        o.Matricula,
                                        o.TipoCarga,
                                        o.Transportista,
                                        o.Comentarios_Dens,
                                        o.Peso_Aire1,
                                        o.Peso_Aire2,
                                        o.Peso_Aire3,
                                        o.Peso_Inmersión1,
                                        o.Peso_Inmersión2,
                                        o.Peso_Inmersión3,
                                        o.DensidadPesada1,
                                        o.DensidadPesada2,
                                        o.DensidadPesada3
                                    });

                    foreach (var q in registre)
                    {
                        Movimiento pdata = new Movimiento();
                        pdata.NumeroDia = q.NumeroDia;
                        pdata.HoraEntrada = q.HoraEntrada;
                        pdata.Matricula = q.Matricula;
                        pdata.TipoCarga = q.TipoCarga;
                        pdata.Transportista = q.Transportista;
                        pdata.Comentarios_Dens = q.Comentarios_Dens;
                        pdata.Peso_Aire1 = q.Peso_Aire1;
                        pdata.Peso_Aire2 = q.Peso_Aire2;
                        pdata.Peso_Aire3 = q.Peso_Aire3;
                        pdata.Peso_Inmersión1 = q.Peso_Inmersión1;
                        pdata.Peso_Inmersión2 = q.Peso_Inmersión2;
                        pdata.Peso_Inmersión3 = q.Peso_Inmersión3;
                        pdata.DensidadPesada1 = q.DensidadPesada1;
                        pdata.DensidadPesada2 = q.DensidadPesada2;
                        pdata.DensidadPesada3 = q.DensidadPesada3;
  
                        _lstMoviment.Add(pdata);

                    }
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstMoviment;
        }


        public List<Movimiento> ConsultarMoviment(int numEntradaAnual, DateTime dDataEntrada)
        {
            List<Movimiento> _lstMoviment = new List<Movimiento>();

            using (ControlWeightEntities bd = new ControlWeightEntities())

            {
                try
                {
                    var registre = (from o in bd.Movimientos
                                    where (o.nMovim == numEntradaAnual &&
                                        o.Fecha == dDataEntrada) 
                                    select o).Single();
                    Movimiento pdata = new Movimiento();
                    pdata.Fabrica = registre.Fabrica;
                    pdata.NumeroDia = registre.NumeroDia;
                    pdata.nMovim = registre.nMovim;
                    pdata.Fecha = registre.Fecha;
                    pdata.Fecha_Salida = registre.Fecha_Salida;
                    pdata.Tipo_Camion = registre.Tipo_Camion;
                    pdata.Tipo_Portes = registre.Tipo_Portes;
                    pdata.TipoCarga = registre.TipoCarga;
                    pdata.Tara = registre.Tara;
                    pdata.PesoMaximo = registre.PesoMaximo;
                    pdata.Matricula = registre.Matricula;
                    pdata.Matricula_Remolque = registre.Matricula_Remolque;
                    pdata.HoraEntrada = registre.HoraEntrada;
                    pdata.HoraSalida = registre.HoraSalida;
                    pdata.PesoEntrada = registre.PesoEntrada;
                    pdata.PesoSalida = registre.PesoSalida;
                    pdata.Diferencia = registre.Diferencia;
                    pdata.Numero_Albaran = registre.Numero_Albaran;
                    pdata.Numero_Bultos = registre.Numero_Bultos;
                    pdata.Cantidad_Entregada = registre.Cantidad_Entregada;
                    //pdata.Cantidad_Pedida = registre.Cantidad_Pedida;
                    pdata.Transportista = registre.Transportista;
                    pdata.Clase_Mercancia = registre.Clase_Mercancia;
                    pdata.Procedencia_Destino = registre.Procedencia_Destino;
                    pdata.Proveedor = registre.Proveedor;
                    pdata.Articulo = registre.Articulo;
                    pdata.Tipo_Unidad = registre.Tipo_Unidad;
                    pdata.Lugar_Descarga = registre.Lugar_Descarga;
                    pdata.Comentarios = registre.Comentarios;
                    pdata.HoraEntrada = registre.HoraEntrada;
                    pdata.Comentarios = registre.Comentarios;
                    
                    _lstMoviment.Add(pdata);
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstMoviment;
        }


        public bool ActualitzarMoviment(int numEntradaAnual, Movimiento moviment)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Movimientos
                                    where o.nMovim == numEntradaAnual
                                    select o).Single();
                    registre.Fabrica = moviment.Fabrica;
                    registre.NumeroDia = moviment.NumeroDia;
                    registre.nMovim = moviment.nMovim;
                    registre.Fecha = moviment.Fecha;
                    registre.Fecha_Salida = moviment.Fecha_Salida;
                    registre.Tipo_Camion = moviment.Tipo_Camion;
                    registre.Tipo_Portes = moviment.Tipo_Portes;
                    registre.TipoCarga = moviment.TipoCarga;
                    registre.Tara = moviment.Tara;
                    registre.PesoMaximo = moviment.PesoMaximo;
                    registre.Matricula = moviment.Matricula;
                    registre.Matricula_Remolque = moviment.Matricula_Remolque;
                    registre.HoraEntrada = moviment.HoraEntrada;
                    registre.HoraSalida = moviment.HoraSalida;
                    registre.PesoEntrada = moviment.PesoEntrada;
                    registre.PesoSalida = moviment.PesoSalida;
                    registre.Numero_Albaran = moviment.Numero_Albaran;
                    registre.Numero_Bultos = moviment.Numero_Bultos;
                    registre.Cantidad_Entregada = moviment.Cantidad_Entregada;
                    registre.Diferencia = moviment.Diferencia;
                    registre.Transportista = moviment.Transportista;
                    registre.Clase_Mercancia = moviment.Clase_Mercancia;
                    registre.Procedencia_Destino = moviment.Procedencia_Destino;
                    registre.Proveedor = moviment.Proveedor;
                    registre.Articulo = moviment.Articulo;
                    registre.Tipo_Unidad = moviment.Tipo_Unidad;
                    registre.Lugar_Descarga = moviment.Lugar_Descarga;
                    registre.Comentarios = moviment.Comentarios;
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                    return false;
                }
            }
        }

        public int NombreEntradaDia(DateTime movimDia)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())

            try
            {
                var registre = (from o in bd.Movimientos
                                where o.Fecha == movimDia
                                select new {o.NumeroDia});

                foreach (var q in registre)
                {
                    numEntrada = q.NumeroDia;
                }
                    
            }
            catch (Exception ex)
            {
                if (ex.ToString() == "")
                {
                    numEntrada = 0;   
                }
                    
            }
            return numEntrada;
        }

        #endregion Moviments

        #region TipusCarrega

        public bool AfegirTipusCarrega(TipoCarga tipusCarrega)
        {
            ControlWeightEntities bd = new ControlWeightEntities();
            bd.TipoCargas.Add(tipusCarrega);
            bd.SaveChanges();
            return true;
        }

        public bool EliminarTipusCarrega(String codiTipusCarrega)
        {

            using (ControlWeightEntities bd = new ControlWeightEntities())
            {

                var registre = (from o in bd.TipoCargas
                                where o.Codigo == codiTipusCarrega
                                select o).Single();

                bd.TipoCargas.Remove(registre);
                bd.SaveChanges();
                return true;
            }

        }

        public List<TipoCarga> LlistaTipusCarrega()
        {
            ControlWeightEntities contexte;

            using (contexte = new ControlWeightEntities())
            {
                List<TipoCarga> _lstTipusCarrega = new List<TipoCarga>();

                foreach (var q in contexte.TipoCargas)
                {
                    TipoCarga pdata = new TipoCarga();
                    pdata.Fabrica = q.Fabrica;
                    pdata.Codigo = q.Codigo;
                    pdata.Descripcion = q.Descripcion;

                    _lstTipusCarrega.Add(pdata);
                }
                return _lstTipusCarrega;

            }           
        }

        public List<TipoCarga> ConsultarTipusCarrega(String codiTipusCarrega)
        {
            List<TipoCarga> _lstTipusCarrega = new List<TipoCarga>();

            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.TipoCargas
                                    where o.Codigo == codiTipusCarrega
                                    select o).Single();
                    TipoCarga pdata = new TipoCarga();
                    pdata.Codigo = registre.Codigo;
                    pdata.Descripcion = registre.Descripcion;
                    _lstTipusCarrega.Add(pdata);
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstTipusCarrega;

        }

        public bool ActualitzarTipusCarrega(String codiTipusCarrega, String sDescripcio)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.TipoCargas
                                    where o.Codigo == codiTipusCarrega
                                    select o).Single();
                    registre.Descripcion = sDescripcio;
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                    return false;
                }
            }
        }
        #endregion TipusCarrega

        #region Comandes

        public bool AfegirComanda(Pedido comanda)
        {
            ControlWeightEntities bd = new ControlWeightEntities();
            bd.Pedidos.Add(comanda);
            bd.SaveChanges();
            return true;
        }

        public bool EliminarComanda(String codiComanda)
        {

            using (ControlWeightEntities bd = new ControlWeightEntities())
            {

                var registre = (from o in bd.Pedidos
                                where o.Pedido1 == codiComanda
                                select o).Single();

                bd.Pedidos.Remove(registre);
                bd.SaveChanges();
                return true;
            }

        }

        public List<Pedido> LlistaComandes()
        {
            throw new NotImplementedException();
        }

        public List<Pedido> ConsultarComanda(Pedido comanda)
        {
            List<Pedido> _lstComanda = new List<Pedido>();

            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Pedidos
                                    where (o.Fabrica == comanda.Fabrica && o.Pedido1 == comanda.Pedido1 && o.Linea_Pedido == comanda.Linea_Pedido)
                                    select o).Single();
                    Pedido pdata = new Pedido();
                    pdata.Fabrica = registre.Fabrica;
                    pdata.Pedido1 = registre.Pedido1;
                    pdata.Linea_Pedido = registre.Linea_Pedido;
                    _lstComanda.Add(pdata);
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstComanda;

        }

        #endregion Comandes

        #region Perfil
        
        public bool AfegirPerfil(Perfil perfil)
        {
            ControlWeightEntities bd = new ControlWeightEntities();
            bd.Perfiles.Add(perfil);
            bd.SaveChanges();
            return true;
        }

        public bool EliminarPerfil(String codiPerfil)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {

                var registre = (from o in bd.Perfiles
                                where o.codi == codiPerfil
                                select o).Single();

                bd.Perfiles.Remove(registre);
                bd.SaveChanges();
                return true;
            }

        }

        public List<Perfil> LlistaPerfils()
        {
            List<Perfil> _lstPerfils = new List<Perfil>();

            ControlWeightEntities contexte;
            using (contexte = new ControlWeightEntities())

            {
                try
                {
                    foreach (var q in contexte.Perfiles)
                    {
                        Perfil pdata = new Perfil();
                        pdata.codi = q.codi;
                        pdata.descripcio = q.descripcio;

                        _lstPerfils.Add(pdata);
                    }
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstPerfils;
        }


        public List<Perfil> ConsultarPerfil(String codiPerfil)
        {
            List<Perfil> _lstPerfil = new List<Perfil>();

            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Perfiles
                                    where o.codi == codiPerfil
                                    select o).Single();
                    Perfil pdata = new Perfil();
                    pdata.descripcio = registre.descripcio;
                    pdata.idu = registre.idu;
                    _lstPerfil.Add(pdata);
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstPerfil;

        }


        public String ConsultarPerfilUsuari(String usuari)
        {    
            using (ControlWeightEntities bd = new ControlWeightEntities())
            
            {
                try
                {
                    var registre = from e in bd.Usuarios
                                    join p in bd.Perfiles
                                    on e.perfil equals p.idu
                                    where e.usuari == usuari
                                    select new { Codi = p.codi };

                    foreach (var pp in registre)
                    {
                        perfil = pp.Codi;
                    }
                    
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                    perfil = "";
                }
            }

            return perfil;
        }


        public bool ActualitzarPerfil(String codiPerfil, String sDescripcio)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Perfiles
                                    where o.codi == codiPerfil
                                    select o).Single();
                    registre.descripcio = sDescripcio;
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                    return false;
                }
            }
        }

        public ArrayList ConsultarMenusSegonsPerfil(String codiPerfil)
        {
            ArrayList _lstMenusSegonsPerfil = new ArrayList();

            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = from r in bd.RelPerfilsMenus
                                   join p in bd.Perfiles
                                   on r.iduPerfil equals p.idu
                                   where p.codi == codiPerfil && r.actiu == true
                                   select new { Codi = r.codiMenu };

                    foreach (var pp in registre)
                    {
                        _lstMenusSegonsPerfil.Add(pp.Codi);
                    }

                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstMenusSegonsPerfil;
        }

        #endregion Perfil

        #region Usuarios

        public bool AfegirUsuari(Usuario usuari)
        {
            ControlWeightEntities bd = new ControlWeightEntities();
            bd.Usuarios.Add(usuari);
            bd.SaveChanges();
            return true;
        }

        public bool EliminarUsuari(String codiUsuari)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {

                var registre = (from o in bd.Usuarios
                                where o.usuari == codiUsuari
                                select o).Single();

                bd.Usuarios.Remove(registre);
                bd.SaveChanges();
                return true;
            }

        }

        public List<Usuario> LlistaUsuaris()
        {
            List<Usuario> _lstUsuaris = new List<Usuario>();

            ControlWeightEntities contexte;
            using (contexte = new ControlWeightEntities())
            {
                try
                {
                    foreach (var q in contexte.Usuarios)
                    {
                        Usuario pdata = new Usuario();
                        pdata.idu = q.idu;
                        pdata.usuari = q.usuari;
                        pdata.nom = q.nom;
                        pdata.email = q.email;
                        pdata.actiu = q.actiu;
                        pdata.perfil = q.perfil;
                        pdata.pass = q.pass;

                        _lstUsuaris.Add(pdata);
                    }
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstUsuaris;
        }


        public List<Usuario> ConsultarUsuari(String codiUsuari)
        {
            List<Usuario> _lstUsuari = new List<Usuario>();

            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Usuarios
                                    where o.usuari == codiUsuari
                                    select o).Single();
                    Usuario pdata = new Usuario();
                    pdata.nom = registre.nom;
                    pdata.pass = registre.pass;
                    pdata.email = registre.email;
                    pdata.actiu = registre.actiu;
                    pdata.perfil = registre.perfil;
                    _lstUsuari.Add(pdata);
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            return _lstUsuari;
        }


        public bool ActualitzarUsuari(String codiUsuari, String sEMail, String sNom, Boolean bActiu, Guid sPerfil, String sPass)
        {
            using (ControlWeightEntities bd = new ControlWeightEntities())
            {
                try
                {
                    var registre = (from o in bd.Usuarios
                                    where o.usuari == codiUsuari
                                    select o).Single();
                    registre.email = sEMail;
                    registre.nom = sNom;
                    registre.actiu = bActiu;
                    registre.perfil = sPerfil;
                    registre.pass = sPass;
                    bd.SaveChanges();
                    return true;
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                    return false;
                }
            }
        }

        #endregion Usuarios

    }
}
