﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

// Namespace que ens permet treballar amb usuaris, ja sigui de windowss o generics d'una bbdd
using System.Security.Principal;
using System.Diagnostics;

//using ControlWeight.WCF;

namespace ControlWeight.WPF
{
    /// <summary>
    /// Lógica de interacción para MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public ArrayList sMenusPerfilUsuari;

        public MainWindow()
        {
            // Abans de inicialitzar l'aplicació comprovarem el valor que retorna la crida a la pantalla Login
            if (!CridaFormLogin())
            {
                // Tanca la aplicació en cas de que la crida a la pantalla Login hagi retornat un false.
                Application.Current.Shutdown(-1);
            }
            else
            {
                InitializeComponent();
                lbUsuari.Content = lbUsuari.Content + " " + System.Threading.Thread.CurrentPrincipal.Identity.Name;

                if (System.Threading.Thread.CurrentPrincipal.IsInRole("ADMIN"))
                {
                    lbPerfil.Content = "Perfil: ADMIN";
                    sMenusPerfilUsuari = BL.PerfilUsuari.LlistaMenusSegonsPerfil("ADMIN");
                }
                else
                {
                    if (System.Threading.Thread.CurrentPrincipal.IsInRole("GESTR"))
                    {
                        lbPerfil.Content = "Perfil: GESTR";
                        sMenusPerfilUsuari = BL.PerfilUsuari.LlistaMenusSegonsPerfil("GESTR");
                    }
                    else
                    {
                        if ((System.Threading.Thread.CurrentPrincipal.IsInRole("APROV")))
                        {
                            lbPerfil.Content = "Perfil: APROV";
                            sMenusPerfilUsuari = BL.PerfilUsuari.LlistaMenusSegonsPerfil("APROV");
                        }
                        else
                        {
                            Application.Current.Shutdown(-1);
                        }
                    }
                }

                if (mnuPral.Items.Count > 0)
                {
                    Explora(mnuPral);
                }
                else
                {
                    MessageBox.Show("No s'han definit camps per el ménú principal");
                }
            }
        }

        private void Explora(Object o)
        {
            Type t = o.GetType();
            switch (t.Name)
            {
                case "Menu":
                    //Debug.Print(string.Format("Menú, Header: {0}, Hijos: {1}", ((Menu)o).Name, ((Menu)o).Items.Count));
                    foreach (Object a in ((Menu)o).Items)
                        Explora(a);
                    break;
                case "MenuItem":
                    //Debug.Print(string.Format("MenuItem, Header: {0}, Hijos: {1}", ((MenuItem)o).Header, ((MenuItem)o).Items.Count));

                    foreach (Object b in ((MenuItem)o).Items)
                        if (sMenusPerfilUsuari.IndexOf(((MenuItem)o).Uid) < 0)
                        {
                            ((MenuItem)o).IsEnabled = false;
                            Explora(b);
                        }
                        else
                        {
                            Explora(b);
                        }
                    break;
                case "Separator":
                    //Debug.Print("Hay un separador");
                    break;
            }
        }


        private Boolean CridaFormLogin()
        {
            Login login = new Login();
            // Crida a la pantalla Login
            login.ShowDialog();
            // La pantalla Login retornarà true o false
            if (login.acceptat)
            {
                //S'utilitzarà l'usuari que s'acaba de login com a usuari per a tota l'aplicació
                //usuari generic no ve de windows, si fos un usuari de windows, utilitzariem .windowsprincipal
                AppDomain.CurrentDomain.SetPrincipalPolicy(PrincipalPolicy.UnauthenticatedPrincipal);
                //Crea una identitat amb el nom d'usuari
                IIdentity usuari = new GenericIdentity(login.tbUsuari.Text, "Database");

                String sPerfilUsuari = BL.PerfilUsuari.NomPerfilUsuari(usuari.Name);
                
                String[] perfils = {sPerfilUsuari};
                //Crea la credencial
                GenericPrincipal credencial = new GenericPrincipal(usuari, perfils);
                //Asignar la credencial a la aplicació
                System.Threading.Thread.CurrentPrincipal = credencial;
                /*  Es podria utilitzat una variables global per utilitzar l'usuari per a tota la aplicació però
                    però amb les linies anteriors utlitzem un esquema que ja s'encarrega de fer-ho i d'una forma mes
                 *  eficient.
                */
            }
            return login.acceptat;
        }

        private void MenuItem_Click_Sortir(object sender, RoutedEventArgs e)
        {
            this.Close();
        }


        private void MenuItem_Click_Trans(object sender, RoutedEventArgs e)
        {  
            frmDadesTransport frmDT = new frmDadesTransport();
            frmDT.ShowDialog();
        }

        private void MenuItem_Click_Densi(object sender, RoutedEventArgs e)
        {
            frmDensimetre frmDD = new frmDensimetre();
            frmDD.ShowDialog();
        }

        private void MenuItem_Click_LoadMAT(object sender, RoutedEventArgs e)
        {
            frmCarregaDades frmLD = new frmCarregaDades();
            frmLD.ShowDialog();
        }


        private void frmMenuItem_Click_User(object sender, RoutedEventArgs e)
        {
            frmUsuaris frmUS = new frmUsuaris();
            frmUS.sTipus = "";
            frmUS.ShowDialog();
        }

        private void MenuItem_Click_Sobre(object sender, RoutedEventArgs e)
        {
            frmAbout frmAO = new frmAbout();
            frmAO.ShowDialog();
        }
    }
}
