﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using ControlWeight.BL;
using ControlWeight.WCF;

namespace ControlWeight.WPF
{
    /// <summary>
    /// Lógica de interacción para frmUsuaris.xaml
    /// </summary>
    public partial class frmUsuaris : Window
    {
        public String sTipus;

        public frmUsuaris()
        {
            InitializeComponent();
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            BL.ServiceReference1.ServicioControlWeightClient client = new BL.ServiceReference1.ServicioControlWeightClient();

            cbPerfils.DisplayMemberPath = "descripcio";
            cbPerfils.SelectedValuePath = "codi";
            cbPerfils.ItemsSource = client.LlistaPerfils();
            ActualitzaGridUsuaris(sTipus);
        }

        private Boolean ActualitzaGridUsuaris(String sTipus)
        {
            Boolean bRetorn;

            try
            {
                NetegarFormulari(sTipus);
                dgUsuaris.Items.Clear();
                dgUsuaris.ItemsSource = null;
                bRetorn = true;
            }
            catch (Exception ex)
            {
                MessageBox.Show("Error inicialitzant Formulari Entrada Moviments. Error" + ex.ToString(), "Error inicalització");
                bRetorn = false;
            }

            try
            {
                foreach (var q in BL.GestioUsuaris.LlistaUsuaris())
                {
                    string sPerf = BL.PerfilUsuari.NomPerfilUsuari(q.usuari);
                    if (String.IsNullOrEmpty(sTipus))
                    {
                        dgUsuaris.Items.Add(new
                        {
                            User = q.usuari,
                            Nom = q.nom,
                            Perfil = sPerf,
                            Actiu = q.actiu,
                            eMail = q.email,
                            Password = q.pass,
                            iduPerfil = q.perfil
                        });
                        bRetorn = true;
                    }
                    else
                    {
                        if ((sTipus.Substring (0,2)).Equals("CP") && (q.usuari == sTipus.Substring (2)))
                        {
                            dgUsuaris.Items.Add(new
                            {
                                User = q.usuari,
                                Nom = q.nom,
                                Perfil = sPerf,
                                Actiu = q.actiu,
                                eMail = q.email,
                                Password = q.pass,
                                iduPerfil = q.perfil
                            });
                            bRetorn = true;
                        }
                        else
                        {
                            bRetorn = false;
                        }
                    }
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("Error en la consulta dels moviments del dia seleccionat. Error" + ex.ToString(), "Error inicalització");
                bRetorn = false;
            }
            return bRetorn;
        }

        private Boolean NetegarFormulari(String sTipus)
        {
            try
            {
                dgUsuaris.SelectedValue = -1;
                tbIdUser.Clear();
                tbNomUser.Clear();
                tbMailUser.Clear();
                cbPerfils.Text = "";
                ckbEstatUser.IsChecked = false;
                tbPassAct.Clear();
                tbPassNou.Clear();
                tbPassNouV.Clear();
                if (!String.IsNullOrEmpty(sTipus))
                {
                    if (sTipus.Substring (0,2).Equals("CP"))
                    {
                        tbIdUser.IsEnabled = false;
                        tbNomUser.IsEnabled = false;
                        tbMailUser.IsEnabled = false;
                        cbPerfils.IsEnabled = false;
                        ckbEstatUser.IsEnabled = false;
                        tbPassAct.IsEnabled = false;
                    }
                }
                return true;
            }
            catch (Exception ex)
            {
                MessageBox.Show("Error netega formulari. " + ex.ToString());
                return false;
            }
        }

        private void dgUsuaris_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            try
            {
                object item = dgUsuaris.SelectedItem;
                if (item == null)
                {
                    return;
                }

                tbIdUser.Text = (dgUsuaris.SelectedCells[0].Column.GetCellContent(item) as TextBlock).Text;
                tbNomUser.Text = (dgUsuaris.SelectedCells[1].Column.GetCellContent(item) as TextBlock).Text;
                tbMailUser.Text = (dgUsuaris.SelectedCells[4].Column.GetCellContent(item) as TextBlock).Text;
                cbPerfils.SelectedValue = BL.PerfilUsuari.NomPerfilUsuari(tbIdUser.Text).ToString();
                cbPerfils.Text = BL.PerfilUsuari.DescPerfilUsuari((dgUsuaris.SelectedCells[2].Column.GetCellContent(item) as TextBlock).Text);
                ckbEstatUser.IsChecked = Convert.ToBoolean((dgUsuaris.SelectedCells[3].Column.GetCellContent(item) as TextBlock).Text);
                tbPassAct.Password = (dgUsuaris.SelectedCells[5].Column.GetCellContent(item) as TextBlock).Text;
            }
            catch (Exception)
            {
                MessageBox.Show("Error cerca dades usuari seleccionat.", "Error");
                throw;
            } 
        }

        private void btGravar_Click(object sender, RoutedEventArgs e)
        {
            Boolean bResultat;
            bResultat = true;

            Usuario user = new Usuario();

            if (VerificaDades() == true)
            {
                user.usuari = tbIdUser.Text;
                user.nom = tbNomUser.Text;
                user.email = tbMailUser.Text;
                //trobar Guid del perfil
                user.perfil = BL.PerfilUsuari.CodiUnicPerfilUsuari(cbPerfils.SelectedValue.ToString());
                user.actiu = (Boolean)ckbEstatUser.IsChecked;
                /*
                 * Verifiquem que no hagi volgut canviar el password,
                 * si es així, verificarem que la contrasenya i la seva verificació
                 * siguin iguals.
                 * Si es així, procedirem a encriptar la password abans de desar el registre
                 */
                if (BL.GestioUsuaris.ConsultarRegistre(user))
                {
                    if ((!String.IsNullOrEmpty(tbPassNou.Password)  && !String.IsNullOrEmpty(tbPassNouV.Password)))
                    {
                        if (BL.General.ComparaPasswords(tbPassNou.Password, tbPassNouV.Password))
                        {
                            user.pass = BL.GestioUsuaris.GeneradorDeHash(tbPassNou.Password);
                            if (BL.GestioUsuaris.GravarRegistre("U", user))
                            {
                                MessageBox.Show("Registre actualitzat correctament", "Registre Usuari");
                                NetegarFormulari(sTipus);
                                ActualitzaGridUsuaris(sTipus);
                            }
                        }
                        else
                        {
                            MessageBox.Show("El password i la seva confirmació son diferents", "Error");
                            tbPassNou.Password = "";
                            tbPassNouV.Password = "";
                        }
                    }
                    else
                    {
                        user.pass = tbPassAct.Password;
                        if (BL.GestioUsuaris.GravarRegistre("U", user))
                        {
                            MessageBox.Show("Registre actualitzat correctament", "Registre Usuari");
                            NetegarFormulari(sTipus);
                            ActualitzaGridUsuaris(sTipus);
                        }
                    }
                }
                else
                {
                    user.pass = BL.GestioUsuaris.GeneradorDeHash(tbPassAct.Password);
                    if (BL.GestioUsuaris.GravarRegistre("I", user))
                    {
                        MessageBox.Show("Registre gravat correctament", "Registre Usuari");
                        NetegarFormulari(sTipus);
                        ActualitzaGridUsuaris(sTipus);
                    }
                }
            }
        }


        private Boolean VerificaDades()
        {
            Boolean bResultat;
            bResultat = true;

            if(String.IsNullOrEmpty(tbIdUser.Text))
            {
                MessageBox.Show("Códi usuari obligatori", "Error");
                bResultat = false;
            }
            if (String.IsNullOrEmpty(tbNomUser.Text))
            {
                MessageBox.Show("Nom usuari obligatori", "Error");
                bResultat = false;
            }
            if (String.IsNullOrEmpty(tbMailUser.Text))
            {
                MessageBox.Show("eMail usuari obligatori", "Error");
                bResultat = false;
            }
            if (String.IsNullOrEmpty(tbPassAct.Password))
            {
                MessageBox.Show("Password usuari obligatori", "Error");
                bResultat = false;
            }

            return bResultat;
        }

        private void cbPerfils_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
        }

    }
}
